{{- define "elasticsearch.server" -}}
{{/* https://logging.apache.org/log4j/2.x/log4j-api/apidocs/org/apache/logging/log4j/Level.html */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "TRACE" "debug" "DEBUG" "info" "INFO" "warn" "WARN" "error" "ERROR" "crit" "FATAL") "component" "elasticsearch" | include "stacklight.logLevel" -}}
clusterName: "elasticsearch"
nodeGroup: "master"
masterService: ""
roles:
  master: "true"
  ingest: "true"
  data: "true"
podManagementPolicy: "OrderedReady"
{{/* solution to ES quorum issues by scaling down the cluster and it's quorum to 0, instead of deleting STS that left a quorum deadlock upon re-enabling logging */}}
{{- if .Values.logging.enabled }}
  {{- if .Values.highAvailabilityEnabled }}
replicas: 3
minimumMasterNodes: 2
maxUnavailable: 1
indexTemplate:
  logstash:
    number_of_replicas: 2
    number_of_shards: 2
  notification:
    number_of_replicas: 2
    number_of_shards: 1
  {{- else }}
replicas: 1
minimumMasterNodes: 1
maxUnavailable: 0
indexTemplate:
  logstash:
    number_of_replicas: 0
    number_of_shards: 1
  notification:
    number_of_replicas: 0
    number_of_shards: 1
  {{- end }}
{{- else }}
replicas: 0
minimumMasterNodes: 0
maxUnavailable: 0
{{- end }}
esMajorVersion: 7
persistence:
  enabled: true
volumeClaimTemplate:
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.elasticsearch }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.elasticsearch }}
    {{- $storageClass = .Values.storage.componentStorageClasses.elasticsearch }}
  {{- end }}
  {{- if (eq "-" $storageClass) }}
  storageClassName: ""
  {{- else }}
  storageClassName: "{{ $storageClass }}"
  {{- end }}
{{- end }}
  resources:
    requests:
      storage: {{ .Values.elasticsearch.persistentVolumeClaimSize }}
secretMounts: []
networkHost: "0.0.0.0"
{{- $resources := mergeOverwrite (index (index .Values.resourcesPerClusterSize "elasticsearch" | default (dict .Values.clusterSize dict)) .Values.clusterSize) (index .Values.resources "elasticsearch") }}
{{- if and (hasKey $resources "limits") (index (default (dict) $resources.limits) "memory") }}
{{- $memoryMap := include "memStringToMap" $resources.limits.memory | fromYaml }}
{{- $maxMemoryInt := index $memoryMap "memory" }}
{{- $unit := index $memoryMap "unit" }}
{{- $maxMemory := div (mul $maxMemoryInt 4) 5 }}
esJavaOpts: "-Xmx{{ $maxMemory }}{{ $unit }} -Xms{{ $maxMemory }}{{ $unit }}"
{{- end }}
extraEnvs:
- name: TAKE_FILE_OWNERSHIP
  value: "true"
esConfig:
  elasticsearch.yml: |
    xpack.ml.enabled: false
    xpack.monitoring.enabled: false
    xpack.security.enabled: false
    xpack.security.audit.enabled: false
    xpack.watcher.enabled: false
    cluster.max_shards_per_node: 5000
  {{- if $logLevel }}
    logger._root.level: {{ $logLevel | quote }}
  {{- end }}
  {{- if .Values.elasticsearch.extraConfig }}
    {{ toYaml .Values.elasticsearch.extraConfig | nindent 4 }}
  {{- end }}
clusterHealthCheckParams: "{{ .Values.elasticsearch.clusterHealthCheckParams }}"

{{ $image := include "stacklight.getImage" (dict "root" . "image" "elasticsearch") | fromYaml }}
image: {{ index $image "repository" | quote }}
imageTag: {{ index $image "tag" }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "elasticsearch") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "elasticsearch") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "elasticsearch") }}
{{- end }}
