{{- define "iamProxy.common" -}}
global:
  dockerBaseUrl: {{ .Values.global.dockerBaseUrl }}
{{- if .Values.global.serviceAnnotations }}
  serviceAnnotations:
    {{- toYaml .Values.global.serviceAnnotations | nindent 4 }}
{{- end }}
service:
  type: LoadBalancer
  port: 80
gatekeeper:
  listen: ":80"
  discoveryUrl: "{{ .Values.iam.url }}/auth/realms/iam"
  clientId: "{{ .Values.iam.client }}"
  clientSecret: "{{ .Values.iam.secret }}"
  skipUpstreamTlsVerify: true
  openid:
    skipTlsVerify: true
  secureCookie: false
  tls:
    enabled: false
  addClaims: []
  {{- $server := .Values.iam.gatekeeper.server }}
  {{- if or $server.readTimeout $server.writeTimeout $server.idleTimeout }}
  server:
    {{- if $server.readTimeout }}
    readTimeout: {{ $server.readTimeout | quote }}
    {{- end }}
    {{- if $server.writeTimeout }}
    writeTimeout: {{ $server.writeTimeout | quote }}
    {{- end }}
    {{- if $server.idleTimeout }}
    idleTimeout: {{ $server.idleTimeout | quote }}
    {{- end }}
  {{- end }}
  {{- $upstream := .Values.iam.gatekeeper.upstream }}
  {{- if or $upstream.keepaliveTimeout $upstream.expectContinueTimeout $upstream.responseHeaderTimeout }}
  upstream:
    {{- if $upstream.keepaliveTimeout }}
    keepaliveTimeout: {{ $upstream.keepaliveTimeout | quote }}
    {{- end }}
    {{- if $upstream.expectContinueTimeout }}
    expectContinueTimeout: {{ $upstream.expectContinueTimeout | quote }}
    {{- end }}
    {{- if $upstream.responseHeaderTimeout }}
    responseHeaderTimeout: {{ $upstream.responseHeaderTimeout | quote }}
    {{- end }}
  {{- end }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "iamProxy") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "iamProxy") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "iamProxy") }}
{{- end -}}

{{- define "iamProxy.alertaOverride" -}}
gatekeeper:
  upstreamUrl: "http://alerta"
  resources:
    main_resource:
      uri: /*
      roles:
        - m:sl:{{ .Values.iam.clusterId }}:alerta@{{ .Values.iam.role }}
{{- end -}}

{{- define "iamProxy.alerta" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyAlertaOverride := include "iamProxy.alertaOverride" . | fromYaml }}
{{- merge $iamProxyAlertaOverride $iamProxyCommon | toYaml }}
{{- end -}}

{{- define "iamProxy.alertmanagerOverride" -}}
gatekeeper:
  upstreamUrl: "http://prometheus-alertmanager"
  resources:
    main_resource:
      uri: /*
      roles:
        - m:sl:{{ .Values.iam.clusterId }}:alertmngmt@{{ .Values.iam.role }}
{{- end -}}

{{- define "iamProxy.alertmanager" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyAlertmanagerOverride := include "iamProxy.alertmanagerOverride" . | fromYaml }}
{{- merge $iamProxyAlertmanagerOverride $iamProxyCommon | toYaml }}
{{- end -}}

{{- define "iamProxy.grafanaOverride" -}}
gatekeeper:
  upstreamUrl: "http://grafana"
  resources:
    main_resource:
      uri: /*
      roles:
        - m:sl:{{ .Values.iam.clusterId }}:grafana@{{ .Values.iam.role }}
{{- end -}}

{{- define "iamProxy.grafana" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyGrafanaOverride := include "iamProxy.grafanaOverride" . | fromYaml }}
{{- merge $iamProxyGrafanaOverride $iamProxyCommon | toYaml }}
{{- end -}}

{{- define "iamProxy.kibanaOverride" -}}
gatekeeper:
  upstreamUrl: "http://kibana"
  resources:
    main_resource:
      uri: /*
      roles:
        - m:sl:{{ .Values.iam.clusterId }}:kibana@{{ .Values.iam.role }}
{{- end -}}

{{- define "iamProxy.kibana" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyKibanaOverride := include "iamProxy.kibanaOverride" . | fromYaml }}
{{- merge $iamProxyKibanaOverride $iamProxyCommon | toYaml }}
{{- end -}}

{{- define "iamProxy.prometheusOverride" -}}
gatekeeper:
  upstreamUrl: "http://prometheus-server"
  resources:
    main_resource:
      uri: /*
      roles:
        - m:sl:{{ .Values.iam.clusterId }}:pm@{{ .Values.iam.role }}
{{- end -}}

{{- define "iamProxy.prometheus" -}}
{{- $iamProxyCommon := include "iamProxy.common" . | fromYaml }}
{{- $iamProxyPrometheusOverride := include "iamProxy.prometheusOverride" . | fromYaml }}
{{- merge $iamProxyPrometheusOverride $iamProxyCommon | toYaml }}
{{- end -}}
