{{- define "stacklight.currentPatroni" -}}
patroni-13
{{- end -}}

{{- define "patroni.common" -}}
{{/* https://docs.python.org/3/library/logging.html#levels */}}
{{- $pgLogLevel := dict "root" $ "logLevels" (dict "trace" "DEBUG" "debug" "DEBUG" "info" "INFO" "warn" "WARNING" "error" "ERROR" "crit" "CRITICAL") "component" "postgresql" | include "stacklight.logLevel" -}}
{{- $exporterLogLevel := dict "root" $ "logLevels" (dict "trace" "debug" "debug" "debug" "info" "info" "warn" "warn" "error" "error" "crit" "error") "component" "postgresql" | include "stacklight.logLevel" -}}
env:
  ALLOW_NOSSL: "true"

patroniConfiguration:
{{- if $pgLogLevel }}
  level: {{ $pgLogLevel | quote }}
{{- end }}
  watchdog:
    mode: off
  postgresql:
    remove_data_directory_on_diverged_timelines: true
    remove_data_directory_on_rewind_failure: true
    parameters:
      log_destination: stderr
      logging_collector: "off"
  bootstrap:
    initdb:
    - encoding: UTF8
    - data-checksums
{{- if .Values.highAvailabilityEnabled }}
    dcs:
      synchronous_mode: true
      synchronous_mode_strict: true
      synchronous_node_count: 1
replicaCount: 3
podDisruptionBudget:
  minAvailable: 50%
{{- else }}
replicaCount: 1
{{- end }}

databases:
- name: grafana
  user: grafana
  pass: grafanadb
{{- if .Values.alerta.enabled }}
- name: alerta
  user: alerta
  pass: alertadb
{{- end }}

metrics:
  postgresql:
    enabled: true
    extraArgs:
    - "--auto-discover-databases"
  {{- if $exporterLogLevel }}
    - "--log.level={{ $exporterLogLevel }}"
  {{- end }}
    {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "pgsqlExporter") | nindent 4 }}
    image:
      {{- $image := include "stacklight.getImage" (dict "root" . "image" "prometheusPostgresExporter") | fromYaml }}
      {{- $repo := splitn "/" 2 (index $image "repository") }}
      {{- $_ := set $image "registry" $repo._0 }}
      {{- $_ := set $image "repository" $repo._1 }}
      {{- $image | toYaml | nindent 6 }}
  patroni:
    enabled: true
  {{- if eq $exporterLogLevel "debug" }}
    extraArgs:
    - "--debug"
  {{- end }}
    {{- include "stacklight.resources" (dict "inTplValues" .Values "service" "patroniExporter") | nindent 4 }}
    image:
      {{- $image := include "stacklight.getImage" (dict "root" . "image" "prometheusPatroniExporter") | fromYaml }}
      {{- $repo := splitn "/" 2 (index $image "repository") }}
      {{- $_ := set $image "registry" $repo._0 }}
      {{- $_ := set $image "repository" $repo._1 }}
      {{- $image | toYaml | nindent 6 }}

persistentVolume:
  enabled: true
  size: 10G
{{- if or .Values.storage.defaultStorageClass .Values.storage.componentStorageClasses.postgresql }}
  {{- $storageClass := .Values.storage.defaultStorageClass }}
  {{- if .Values.storage.componentStorageClasses.postgresql }}
    {{- $storageClass = .Values.storage.componentStorageClasses.postgresql }}
  {{- end }}
  storageClass: "{{ $storageClass }}"
{{- end }}

{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "postgresql") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "postgresql") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "postgresql") }}
{{- end -}}

{{- define "patroni.override13" -}}
{{- $releaseName := "patroni-13" }}
# major PG version upgrades require appropriate split-aways from common reference
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "spilo") | nindent 2 }}
{{- if .Values.highAvailabilityEnabled }}
affinity:
  podAntiAffinity:
    requiredDuringSchedulingIgnoredDuringExecution:
    - topologyKey: "kubernetes.io/hostname"
      labelSelector:
        matchLabels:
          app: patroni
          release: {{ $releaseName }}
{{- end }}
{{- end -}}

{{- define "patroni.13" -}}
{{- $patroniCommon := include "patroni.common" . | fromYaml }}
{{- $patroniOverride13 := include "patroni.override13" . | fromYaml }}
{{- merge $patroniOverride13 $patroniCommon | toYaml }}
{{- end -}}
