{{- define "prometheus.blackboxExporter" -}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "debug" "debug" "debug" "info" "info" "warn" "warn" "error" "error" "crit" "error") "component" "prometheusBlackboxExporter" | include "stacklight.logLevel" -}}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "blackboxExporter") | nindent 2 }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "blackboxExporter") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "prometheusBlackboxExporter") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "prometheusBlackboxExporter") }}
{{- $isMKEEnabled := .Values.mke.enabled }}
{{- $hasExternalCerts := and .Values.externalEndpointMonitoring.enabled (ne .Values.externalEndpointMonitoring.certificatesHostPath "") }}
{{- if or $isMKEEnabled $hasExternalCerts }}
extraVolumes:
  {{- if $isMKEEnabled }}
- name: mkecerts
  hostPath:
    path: "{{ .Values.mke.dockerdDataRoot }}/volumes/ucp-node-certs/_data"
  {{- end }}
  {{- if $hasExternalCerts }}
- name: externalcerts
  hostPath:
    path: "{{ .Values.externalEndpointMonitoring.certificatesHostPath }}"
  {{- end }}
extraVolumeMounts:
  {{- if $isMKEEnabled }}
- name: mkecerts
  mountPath: /tmp/mkecerts
  {{- end }}
  {{- if $hasExternalCerts }}
- name: externalcerts
  mountPath: /tmp/externalcerts
  {{- end }}
{{- end }}
{{- if $logLevel }}
extraArgs:
- --log.level={{ $logLevel }}
{{- end }}
config:
  modules:
    tls_verify:
      prober: tcp
      tcp:
        tls: true
        preferred_ip_protocol: ip4
    tls:
      prober: tcp
      tcp:
        tls: true
        tls_config:
          insecure_skip_verify: true
        preferred_ip_protocol: ip4
    http_2xx_verify:
      prober: http
      http:
        {{- if $hasExternalCerts }}
        tls_config:
          ca_file: /tmp/externalcerts/ca.pem
          cert_file: /tmp/externalcerts/cert.pem
          key_file: /tmp/externalcerts/key.pem
        {{- end }}
        bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
        preferred_ip_protocol: ip4
    http_2xx:
      http:
        tls_config:
        {{- if .Values.mke.enabled }}
          ca_file: /tmp/mkecerts/ca.pem
          cert_file: /tmp/mkecerts/cert.pem
          key_file: /tmp/mkecerts/key.pem
        {{- end }}
          insecure_skip_verify: true
        bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
        preferred_ip_protocol: ip4
{{- if .Values.openstack.enabled }}
    http_openstack:
      prober: http
      http:
        valid_status_codes: [200,300]
        {{- if $hasExternalCerts }}
        tls_config:
          ca_file: /tmp/externalcerts/ca.pem
          cert_file: /tmp/externalcerts/cert.pem
          key_file: /tmp/externalcerts/key.pem
        {{- end }}
        bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
        preferred_ip_protocol: ip4
    http_openstack_insecure:
      prober: http
      http:
        valid_status_codes: [200,300]
        tls_config:
          insecure_skip_verify: true
        bearer_token_file: /var/run/secrets/kubernetes.io/serviceaccount/token
        preferred_ip_protocol: ip4
{{- end }}
configmapReload:
  image:
    {{- include "stacklight.getImage" (dict "root" . "image" "configmapReload") | nindent 4 }}
{{- end }}
