{{- define "prometheus.esExporter" -}}
{{/* https://docs.python.org/3/library/logging.html#levels */}}
{{- $logLevel := dict "root" $ "logLevels" (dict "trace" "DEBUG" "debug" "DEBUG" "info" "INFO" "warn" "WARNING" "error" "ERROR" "crit" "CRITICAL") "component" "prometheusEsExporter" | include "stacklight.logLevel" }}
es:
  uri: elasticsearch-master:9200
extraArgs:
- "--nodes-stats-disable"
- "--cluster-health-disable"
- "--indices-stats-disable"
{{- if $logLevel }}
- "--log-level={{ $logLevel }}"
{{- end }}
image:
  {{- include "stacklight.getImage" (dict "root" . "image" "prometheusEsExporter") | nindent 2 }}
{{- include "stacklight.resources" (dict "inTplValues" .Values "service" "prometheusEsExporter") }}
{{- include "stacklight.nodeSelector" (dict "inTplValues" .Values "service" "prometheusEsExporter") }}
{{- include "stacklight.tolerations" (dict "inTplValues" .Values "service" "prometheusEsExporter") }}
{{- if .Values.openstack.enabled }}
extraQueries:
  compute_instance_create_start:
    # Produces metrics:
    #   - compute_instance_create_start_event_doc_count
    #   - compute_instance_create_start_event_sum_other_doc_count
    #   - compute_instance_create_start_event_doc_count_error_upper_bound
    #   - compute_instance_create_start_hits
    #   - compute_instance_create_start_took_milliseconds
    #
    indices: '<notification-{now/d}>'
    interval: 60
    body:
      size: 0
      aggs:
        event:
          filter:
            term:
              event_type: "compute.instance.create.start"

  compute_instance_create_end:
    # Produces metrics:
    #   - compute_instance_create_end_event_doc_count
    #   - compute_instance_create_end_event_sum_other_doc_count
    #   - compute_instance_create_end_event_doc_count_error_upper_bound
    #   - compute_instance_create_end_hits
    #   - compute_instance_create_end_took_milliseconds
    #
    indices: '<notification-{now/d}>'
    interval: 60
    body:
      size: 0
      aggs:
        event:
          filter:
            term:
              event_type: "compute.instance.create.end"

  compute_instance_create_error:
    # Produces metrics:
    #   - compute_instance_create_error_event_doc_count
    #   - compute_instance_create_error_event_sum_other_doc_count
    #   - compute_instance_create_error_event_doc_count_error_upper_bound
    #   - compute_instance_create_error_hits
    #   - compute_instance_create_error_took_milliseconds
    #
    indices: '<notification-{now/d}>'
    interval: 60
    body:
      size: 0
      aggs:
        event:
          filter:
            term:
              event_type: "compute.instance.create.error"
{{- end }}
{{- end -}}
